package com.plannaplan.services;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringRunner;

import static org.junit.Assert.assertTrue;

import java.io.InputStream;
import java.sql.Date;

import com.plannaplan.TestApplication;
import com.plannaplan.entities.AppConfig;
import com.plannaplan.models.ConfigData;
import com.plannaplan.models.TourData;
import com.plannaplan.repositories.AppConfigRepository;

import org.junit.Test;
import org.junit.runner.RunWith;

@RunWith(SpringRunner.class)
@SpringBootTest
@ContextConfiguration
public class ConfiguratorServiceTest {

    @Autowired
    private ConfiguratorService configuratorService;

    @Autowired
    private CourseService courseService;

    @Autowired
    private GroupService groupService;

    @Autowired
    private LecturerService lecturerService;

    @Autowired
    private AppConfigRepository appConfigRepo;

    @Test
    public void shouldImportDataToDataBase() {
        final InputStream inputStream = getClass().getClassLoader()
                .getResourceAsStream(TestApplication.TEST_CONFIG_FILE);
        final ConfigData data = new ConfigData(
                new TourData(new Date(System.currentTimeMillis()), new Date(System.currentTimeMillis() + 86400000)),
                new TourData(new Date(System.currentTimeMillis() + 86400000),
                        new Date(System.currentTimeMillis() + 2 * 86400000)),
                inputStream);
        this.configuratorService.config(data);

        int courses_ammount = this.courseService.getCoursesAmmount();
        int groups_ammount = this.groupService.getGroupsAmmount();
        int lecturers_ammount = this.lecturerService.getLecturersAmmount();

        assertTrue(courses_ammount > 0 && groups_ammount > 0 && lecturers_ammount > 0);
    }

    @Test
    public void shouldRetrunNewestConfig() throws InterruptedException {
        final Date dateToCheck = new Date(System.currentTimeMillis());
        this.appConfigRepo.save(new AppConfig(new TourData(null, null), new TourData(null, null)));
        Thread.sleep(2000);
        this.appConfigRepo.save(new AppConfig(new TourData(dateToCheck, null), new TourData(null, null)));

        AppConfig response = this.configuratorService.getCurrentConfig();
        assertTrue(response.getFirstTourStart() != null);

    }

}
